==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/systemtags/l10n/tr.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Etiketler",
    "Update" : "Güncelle",
    "Create" : "Ekle",
    "Select tag…" : "Etiket seçin...",
    "Tagged files" : "Etiketli dosyalar",
    "Select tags to filter by" : "Süzülecek etiketleri seçin",
    "No tags found" : "Herhangi bir etiket bulunamadı",
    "Please select tags to filter by" : "Lütfen süzülecek etiketleri seçin",
    "No files found for the selected tags" : "Seçilmiş etiketlere uyan bir dosya bulunamadı",
    "Added system tag %1$s" : "%1$s sistem etiketi eklendi",
    "Added system tag {systemtag}" : "{systemtag} sistem etiketi eklendi",
    "%1$s added system tag %2$s" : "%1$s, %2$s sistem etiketini ekledi",
    "{actor} added system tag {systemtag}" : "{actor}, {systemtag} sistem etiketini ekledi",
    "Removed system tag %1$s" : "%1$s sistem etiketi silindi",
    "Removed system tag {systemtag}" : "{systemtag} sistem etiketi silindi",
    "%1$s removed system tag %2$s" : "%1$s, %2$s sistem etiketini sildi",
    "{actor} removed system tag {systemtag}" : "{actor}, {systemtag} sistem etiketini sildi",
    "You created system tag %1$s" : "%1$s sistem etiketini eklediniz",
    "You created system tag {systemtag}" : "{systemtag} sistem etiketini eklediniz",
    "%1$s created system tag %2$s" : "%1$s, %2$s sistem etiketini ekledi",
    "{actor} created system tag {systemtag}" : "{actor}, {systemtag} sistem etiketini ekledi",
    "You deleted system tag %1$s" : "%1$s sistem etiketini sildiniz",
    "You deleted system tag {systemtag}" : "{systemtag} sistem etiketini sildiniz",
    "%1$s deleted system tag %2$s" : "%1$s, %2$s sistem etiketini sildi",
    "{actor} deleted system tag {systemtag}" : "{actor}, {systemtag} sistem etiketini sildi",
    "You updated system tag %2$s to %1$s" : "%2$s sistem etiketini %1$s olarak güncellediniz",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "{oldsystemtag} sistem etiketini {newsystemtag} olarak güncellediniz",
    "%1$s updated system tag %3$s to %2$s" : "%1$s, %3$s sistem etiketini %2$s olarak güncelledi",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor}, {oldsystemtag} sistem etiketini {newsystemtag} olarak güncelledi",
    "You added system tag %2$s to %1$s" : "%2$s sistem etiketini %1$s dosyasına eklediniz",
    "You added system tag {systemtag} to {file}" : "{systemtag} sistem etiketini {file} dosyasına eklediniz",
    "%1$s added system tag %3$s to %2$s" : "%1$s, %3$s sistem etiketini %2$s dosyasına ekledi",
    "{actor} added system tag {systemtag} to {file}" : "{actor}, {systemtag} sistem etiketini {file} dosyasına eklediniz",
    "You removed system tag %2$s from %1$s" : "%2$s sistem etiketini %1$s dosyasından sildiniz",
    "You removed system tag {systemtag} from {file}" : "{systemtag} sistem etiketini {file} dosyasından sildiniz",
    "%1$s removed system tag %3$s from %2$s" : "%1$s, %3$s sistem etiketini %2$s dosyasından sildi",
    "{actor} removed system tag {systemtag} from {file}" : "{actor}, {systemtag} sistem etiketini {file} dosyasından sildi",
    "%s (restricted)" : "%s (kısıtlı)",
    "%s (invisible)" : "%s (gizli)",
    "<strong>System tags</strong> for a file have been modified" : "Bir dosyanın <strong>sistem etiketleri</strong> değiştirildi",
    "Collaborative tags" : "İşbirliği etiketleri",
    "Create and edit collaborative tags. These tags affect all users." : "İşbirliği etiketlerini oluşturun ve düzenleyin. Bu etiketler tüm kullanıcıları etkiler.",
    "Select tag …" : "Etiket seçin...",
    "Name" : "Ad",
    "Delete" : "Sil",
    "Public" : "Herkese açık",
    "Restricted" : "Kısıtlı",
    "Invisible" : "Gizli",
    "Reset" : "Sıfırla",
    "No files in here" : "Burada herhangi bir dosya yok",
    "No entries found in this folder" : "Bu klasörde herhangi bir kayıt bulunamadı",
    "Size" : "Boyut",
    "Modified" : "Değiştirilme"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-13.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/systemtags/l10n/tr.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Etiketler",
    "Update" : "Güncelle",
    "Create" : "Ekle",
    "Select tag…" : "Etiket seçin...",
    "Tagged files" : "Etiketli dosyalar",
    "Select tags to filter by" : "Süzülecek etiketleri seçin",
    "No tags found" : "Herhangi bir etiket bulunamadı",
    "Please select tags to filter by" : "Lütfen süzülecek etiketleri seçin",
    "No files found for the selected tags" : "Seçilmiş etiketlere uyan bir dosya bulunamadı",
    "Added system tag %1$s" : "%1$s sistem etiketi eklendi",
    "Added system tag {systemtag}" : "{systemtag} sistem etiketi eklendi",
    "%1$s added system tag %2$s" : "%1$s, %2$s sistem etiketini ekledi",
    "{actor} added system tag {systemtag}" : "{actor}, {systemtag} sistem etiketini ekledi",
    "Removed system tag %1$s" : "%1$s sistem etiketi silindi",
    "Removed system tag {systemtag}" : "{systemtag} sistem etiketi silindi",
    "%1$s removed system tag %2$s" : "%1$s, %2$s sistem etiketini sildi",
    "{actor} removed system tag {systemtag}" : "{actor}, {systemtag} sistem etiketini sildi",
    "You created system tag %1$s" : "%1$s sistem etiketini eklediniz",
    "You created system tag {systemtag}" : "{systemtag} sistem etiketini eklediniz",
    "%1$s created system tag %2$s" : "%1$s, %2$s sistem etiketini ekledi",
    "{actor} created system tag {systemtag}" : "{actor}, {systemtag} sistem etiketini ekledi",
    "You deleted system tag %1$s" : "%1$s sistem etiketini sildiniz",
    "You deleted system tag {systemtag}" : "{systemtag} sistem etiketini sildiniz",
    "%1$s deleted system tag %2$s" : "%1$s, %2$s sistem etiketini sildi",
    "{actor} deleted system tag {systemtag}" : "{actor}, {systemtag} sistem etiketini sildi",
    "You updated system tag %2$s to %1$s" : "%2$s sistem etiketini %1$s olarak güncellediniz",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "{oldsystemtag} sistem etiketini {newsystemtag} olarak güncellediniz",
    "%1$s updated system tag %3$s to %2$s" : "%1$s, %3$s sistem etiketini %2$s olarak güncelledi",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor}, {oldsystemtag} sistem etiketini {newsystemtag} olarak güncelledi",
    "You added system tag %2$s to %1$s" : "%2$s sistem etiketini %1$s dosyasına eklediniz",
    "You added system tag {systemtag} to {file}" : "{systemtag} sistem etiketini {file} dosyasına eklediniz",
    "%1$s added system tag %3$s to %2$s" : "%1$s, %3$s sistem etiketini %2$s dosyasına ekledi",
    "{actor} added system tag {systemtag} to {file}" : "{actor}, {systemtag} sistem etiketini {file} dosyasına eklediniz",
    "You removed system tag %2$s from %1$s" : "%2$s sistem etiketini %1$s dosyasından sildiniz",
    "You removed system tag {systemtag} from {file}" : "{systemtag} sistem etiketini {file} dosyasından sildiniz",
    "%1$s removed system tag %3$s from %2$s" : "%1$s, %3$s sistem etiketini %2$s dosyasından sildi",
    "{actor} removed system tag {systemtag} from {file}" : "{actor}, {systemtag} sistem etiketini {file} dosyasından sildi",
    "%s (restricted)" : "%s (kısıtlı)",
    "%s (invisible)" : "%s (gizli)",
    "<strong>System tags</strong> for a file have been modified" : "Bir dosyanın <strong>sistem etiketleri</strong> değiştirildi",
    "Collaborative tags" : "İşbirliği etiketleri",
    "Collaborative tagging functionality which shares tags among users." : "Etiketlerin kullanıcılar arasında paylaşılabilmesini sağlayan işbirlikli etiketleme özelliği.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "İşbirlikli etiketleme özelliği etiketlerin kullanıcılar arasında paylaşılabilmesini sağlar. Takımlar için harikadır. \n\t(Birden çok kuruluşun olduğu bir kurulumda etiketler zaten paylaşıldığı için bu uygulamanın devre dışı bırakılması önerilir).",
    "Create and edit collaborative tags. These tags affect all users." : "İşbirliği etiketlerini oluşturun ve düzenleyin. Bu etiketler tüm kullanıcıları etkiler.",
    "Select tag …" : "Etiket seçin...",
    "Name" : "Ad",
    "Delete" : "Sil",
    "Public" : "Herkese açık",
    "Restricted" : "Kısıtlı",
    "Invisible" : "Gizli",
    "Reset" : "Sıfırla",
    "No files in here" : "Burada herhangi bir dosya yok",
    "No entries found in this folder" : "Bu klasörde herhangi bir kayıt bulunamadı",
    "Size" : "Boyut",
    "Modified" : "Değiştirilme"
},
"nplurals=2; plural=(n > 1);");
